@@ -46,7 +46,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{.*?/latex/seqdiag-.*?.png}')
+        self.assertRegexpMatches(source, '\\\\includegraphics{seqdiag-.*?.png}')
 
     @unittest.skipUnless(os.path.exists(seqdiag_fontpath), "TrueType font not found")
     @unittest.skipIf(sys.version_info[:2] == (3, 2), "reportlab does not support python 3.2")
@@ -59,7 +59,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{.*?/latex/seqdiag-.*?.pdf}')
+        self.assertRegexpMatches(source, '\\\\includegraphics{seqdiag-.*?.pdf}')
 
     @unittest.skipUnless(os.path.exists(seqdiag_fontpath), "TrueType font not found")
     @unittest.skipIf(sys.version_info[:2] == (3, 2), "reportlab does not support python 3.2")
@@ -72,7 +72,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{.*?/latex/seqdiag-.*?.pdf}')
+        self.assertRegexpMatches(source, '\\\\includegraphics{seqdiag-.*?.pdf}')
 
     @with_png_app
     def test_width_option(self, app, status, warning):
@@ -84,7 +84,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics\\[width=3cm\\]{.*?/latex/seqdiag-.*?.png}')
+        self.assertRegexpMatches(source, '\\\\includegraphics\\[width=3cm\\]{seqdiag-.*?.png}')
 
     @with_png_app
     def test_height_option(self, app, status, warning):
@@ -96,7 +96,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics\\[height=4cm\\]{.*?/latex/seqdiag-.*?.png}')
+        self.assertRegexpMatches(source, '\\\\includegraphics\\[height=4cm\\]{seqdiag-.*?.png}')
 
     @with_png_app
     def test_scale_option(self, app, status, warning):
@@ -108,7 +108,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\scalebox{0.500000}{\\\\includegraphics{.*?/latex/seqdiag-.*?.png}}')
+        self.assertRegexpMatches(source, '\\\\scalebox{0.500000}{\\\\includegraphics{seqdiag-.*?.png}}')
 
     @with_png_app
     def test_align_option_left(self, app, status, warning):
@@ -120,7 +120,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '{\\\\includegraphics{.*?/latex/seqdiag-.*?.png}\\\\hfill}')
+        self.assertRegexpMatches(source, '{\\\\includegraphics{seqdiag-.*?.png}\\\\hfill}')
 
     @with_png_app
     def test_align_option_center(self, app, status, warning):
@@ -132,7 +132,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '{\\\\hfill\\\\includegraphics{.*?/latex/seqdiag-.*?.png}\\\\hfill}')
+        self.assertRegexpMatches(source, '{\\\\hfill\\\\includegraphics{seqdiag-.*?.png}\\\\hfill}')
 
     @with_png_app
     def test_align_option_right(self, app, status, warning):
@@ -144,7 +144,7 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '{\\\\hfill\\\\includegraphics{.*?/latex/seqdiag-.*?.png}}')
+        self.assertRegexpMatches(source, '{\\\\hfill\\\\includegraphics{seqdiag-.*?.png}}')
 
     @with_png_app
     def test_caption_option(self, app, status, warning):
@@ -156,9 +156,9 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{.*?/latex/seqdiag-.*?.png}')
+        self.assertRegexpMatches(source, '\\\\includegraphics{seqdiag-.*?.png}')
 
-        figure = re.compile('\\\\begin{figure}\\[htbp\\]\n\\\\centering.*?'
+        figure = re.compile('\\\\begin{figure}\\[htbp\\]\r?\n\\\\centering.*?'
                             '\\\\caption{hello world}\\\\end{figure}', re.DOTALL)
         self.assertRegexpMatches(source, figure)
 
@@ -173,8 +173,20 @@ class TestSphinxcontribSeqdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{.*?/latex/seqdiag-.*?.png}')
+        self.assertRegexpMatches(source, '\\\\includegraphics{seqdiag-.*?.png}')
 
         figure = re.compile('\\\\begin{figure}\\[htbp\\]\\\\begin{flushleft}.*?'
                             '\\\\caption{hello world}\\\\end{flushleft}\\\\end{figure}', re.DOTALL)
         self.assertRegexpMatches(source, figure)
+
+    @with_png_app
+    def test_href(self, app, status, warning):
+        """
+        .. seqdiag::
+
+           A -> B;
+           A [href=":ref:`target`"];
+        """
+        app.builder.build_all()
+        source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
+        self.assertRegexpMatches(source, '\\\\includegraphics{seqdiag-.*?.png}')
